==> composabl_core_dev-0.8.0.dev51-cp310-cp310-manylinux_2_17_aarch64.manylinux2014_aarch64.whl: composabl_core/examples/demo_coordinated/sim/sim.py <==
# Copyright (C) Composabl, Inc - All Rights Reserved
# Unauthorized copying of this file, via any medium is strictly prohibited
# Proprietary and confidential

import gymnasium as gym

import composabl_core.utils.logger as logger_util
from composabl_core.agent.scenario.scenario import Scenario

logger = logger_util.get_logger(__name__)


class Sim(gym.Env):
    def __init__(self, env_init: dict = {}):
        # Define the initial values
        self.time_ticks = 0
        self.value = 0
        self.is_done = False
        self.steps = 0

        # Define the sensor and action spaces
        self.sensor_space = gym.spaces.Dict({
            "state1": gym.spaces.Box(low=-1e12, high=1e12),
            "time_ticks": gym.spaces.Box(low=0, high=1e12)
        })

        self.action_space = gym.spaces.Dict({
            "skill1": gym.spaces.Discrete(3),
            "skill2": gym.spaces.Discrete(3)
        })

        # Define the scenario
        self.scenario: Scenario = None

    def _get_sensor_values(self):
        obs = {"state1": self.value, "time_ticks": self.time_ticks}
        return obs

    def reset(self):
        self.time_ticks = 0
        self.value = 0
        self.is_done = False
        self.steps = 0

        obs = self._get_sensor_values()
        info = {}

        return obs, info

    def set_scenario(self, scenario):
        self.scenario = scenario

    def step(self, action):
        # Increase time counting
        self.time_ticks += 1
        self.steps += 1

        assert self.action_space.contains(action), f"Invalid action: {action}"

        #  Update obs with new state values (dummy function)
        obs = self._get_sensor_values()
        reward = 0
        info = {}

        if self.steps > 10:
            self.is_done = True

        return obs, reward, self.is_done, False, info

==> composabl_core_dev-0.10.0.dev20-cp310-cp310-manylinux_2_17_aarch64.manylinux2014_aarch64.whl: composabl_core/examples/demo_coordinated/sim/sim.py <==
# Copyright (C) Composabl, Inc - All Rights Reserved
# Unauthorized copying of this file, via any medium is strictly prohibited
# Proprietary and confidential

import gymnasium as gym

import composabl_core.utils.logger as logger_util
from composabl_core.agent.scenario.scenario import Scenario

logger = logger_util.get_logger(__name__)


class Sim(gym.Env):
    def __init__(self, env_init: dict = {}):
        # Define the initial values
        self.time_ticks = 0
        self.value = 0
        self.is_done = False
        self.steps = 0

        # Define the sensor and action spaces
        self.sensor_space = gym.spaces.Dict({
            "state1": gym.spaces.Box(low=-1e12, high=1e12),
            "time_ticks": gym.spaces.Box(low=0, high=1e12)
        })

        self.action_space = gym.spaces.Dict({
            "skill1": gym.spaces.Discrete(3),
            "skill2": gym.spaces.Discrete(3)
        })

        # Define the scenario
        self.scenario: Scenario = None

    def _get_sensor_values(self):
        sensors = {"state1": self.value, "time_ticks": self.time_ticks}
        return sensors

    def reset(self):
        self.time_ticks = 0
        self.value = 0
        self.is_done = False
        self.steps = 0

        sensors = self._get_sensor_values()
        info = {}

        return sensors, info

    def set_scenario(self, scenario):
        self.scenario = scenario

    def step(self, action):
        # Increase time counting
        self.time_ticks += 1
        self.steps += 1

        assert self.action_space.contains(action), f"Invalid action: {action}"

        #  Update sensors with new state values (dummy function)
        sensors = self._get_sensor_values()
        reward = 0
        info = {}

        if self.steps > 10:
            self.is_done = True

        return sensors, reward, self.is_done, False, info
